@@ -15,7 +15,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_appsync.paginator import (
     ListApiKeysPaginator,
@@ -369,7 +369,7 @@ class AppSyncClient:
         """
 
     def start_schema_creation(
-        self, apiId: str, definition: bytes
+        self, apiId: str, definition: Union[bytes, IO[bytes]]
     ) -> StartSchemaCreationResponseTypeDef:
         """
         [Client.start_schema_creation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/appsync.html#AppSync.Client.start_schema_creation)
